Crate cjam

Crate cjam 

cargo-jam

Jam service builder based on the fork of jam-pvm-build by the polkajam team with sort of fixes.

Re-exports

pub use manifest::ModuleType;
pub use manifest::Profile;
pub use util::build;
pub use clap;

Modules

builder
Builder logic for creating PVM code blobs for execution on the JAM PVM instances (service code and authorizer code).
cmd
Command registry
manifest
Cargo manifest related utilities
util
Utility functions for the PVM CLI

Macros

pvm_binary
Macro to include the PVM binary